import 'package:contentsquare/src/modules/screengraph/screengraph_explorer.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  group('Screengraph Generator', () {
    group('generateScreengraph', () {
      testWidgets(
          'should return a screengraph with fullpath containing no private widgets',
          (WidgetTester tester) async {
        await tester.pumpWidget(const Directionality(
          textDirection: TextDirection.ltr,
          child: Material(),
        ));

        //With private widget skipping: FakeRootPath>RenderObjectToWidgetAdapter:eq(0)>Directionality:eq(0)>Material:eq(0)>AnimatedPhysicalModel:eq(0)>PhysicalModel:eq(0)>NotificationListener:eq(0)
        //Without private widget skipping: FakeRootPath>RenderObjectToWidgetAdapter:eq(0)>Directionality:eq(0)>Material:eq(0)>AnimatedPhysicalModel:eq(0)>PhysicalModel:eq(0)>NotificationListener:eq(0)>_InkFeatures:eq(0)

        var screengraph = await ScreengraphGenerator()
            .generateScreengraph("FakeRootPath", pixelRatio: 1.0);
        expect(
            screengraph[0]['children'][0]['children'][0]['children'][0]
                ['children'][0]['children'][0]['metadata']['fullpath'],
            "FakeRootPath>RenderObjectToWidgetAdapter:eq(0)>Directionality:eq(0)>Material:eq(0)>AnimatedPhysicalModel:eq(0)>PhysicalModel:eq(0)>NotificationListener:eq(0)");
      });
    });

    group('ScreengraphScanner', () {
      group('scanRootForCandidateElementsAtPosition', () {
        testWidgets(
            'should return a path to the given targetable widget [ElevatedButton] only (without its children)',
            (WidgetTester tester) async {
          tester.binding.window.physicalSizeTestValue = const Size(100, 100);

          await tester.pumpWidget(
            MaterialApp(
              home: ElevatedButton(
                onPressed: () {},
                child: const Text("Hello"),
              ),
            ),
          );

          var touchedPosition = const Offset(0.0, 0.0);
          var elementPath = ScreengraphScanner()
              .scanRootForCandidateElementsAtPosition(touchedPosition);

          expect(
            elementPath,
            endsWith('ElevatedButton:eq(0)'),
          );
        });
      });
    });
  });
}
